.. image:: ../_static/CSAwesomeLogo.png
    :width: 350
    :align: center

==========================================
AP CSA Java Course
==========================================

Welcome to CSAwesome! It's time to start your journey to learn how to program with Java. A shortcut way to get to this site is to type in the url: **course.csawesome.org**

CSAwesome is a College Board endorsed curriculum for AP Computer Science A, an introductory college-level computer programming course in Java.  If you are a teacher using this curriculum, please join the |teaching CSAwesome group| which will give you access to teacher resources at |csawesome|.

To make sure the site saves your answers on questions, please click on the person icon at the top to register or login to your Runestone course. As you complete lessons, click the "Mark as completed" button at the bottom. Enjoy the journey!

.. |flyer| raw:: html

   <a href="https://drive.google.com/file/d/11MDPfpb3sjzfCR-6zeUe79WNgBbfZbqN/view?usp=sharing" target="_blank" style="text-decoration:underline">flyer</a>


ATTENTION high school women of color taking AP CSA or CSP: if you identify as female and as Black, Hispanic/Latina, and/or Native American, apply to participate in **Sisters Rise Up**. The goal of Sisters Rise Up is to help you succeed in your AP Computer Science course and on the exam. They offer one-hour help sessions several times a week and once a month special help sessions often with guest speakers from computing.  If you enroll in Sisters Rise Up and send in your AP CS exam score by the end of August, you will be sent a gift card for $100. See the |flyer| and apply at https://tinyurl.com/55z7tyb9.

.. ATTENTION high school women, genderqueer, and non-binary technologists: Apply Sept. 1st until Oct. 20th for the **NCWIT Award for Aspirations in Computing** to be recognized for all that you do (or want to do) in technology. Visit http://www.aspirations.org/AiCHSAward for details. 

.. ATTENTION high school seniors: apply for the https://www.amazonfutureengineer.com/scholarships until Dec. 15th for college scholarships and Amazon summer internships for students with financial need.

.. Apply for the  ACM Cutler-Bell Scholarship https://csteachers.org/awards/cutlerbell/ until Jan. 19th.

**CSAwesome Units:**

.. raw:: html

    <ul id="small_toc"></ul>

.. Here is where you specify the content and order of your new book.

.. Each section heading (e.g. "SECTION 1: A Random Section") will be
   a heading in the table of contents. Source files that should be
   generated and included in that section should be placed on individual
   lines, with one line separating the first source filename and the
   :maxdepth: line.

.. Sources can also be included from subfolders of this directory.
   (e.g. "DataStructures/queues.rst").


Table of Contents
:::::::::::::::::


.. raw:: html

   <ul>
   <li><a href="/runestone/assignments/chooseAssignment.html">Assignments</a></li>
   </ul>


.. toctree::
   :numbered:
   :maxdepth: 3

   Unit1-Getting-Started/toctree.rst
   Unit2-Using-Objects/toctree.rst
   Unit3-If-Statements/toctree.rst
   Unit4-Iteration/toctree.rst
   Unit5-Writing-Classes/toctree.rst
   Unit6-Arrays/toctree.rst
   Unit7-ArrayList/toctree.rst
   Unit8-2DArray/toctree.rst
   Unit9-Inheritance/toctree.rst
   Unit10-Recursion/toctree.rst
   Unit11-posttest/toctree.rst
   Tests/toctree.rst
   TimedTests/toctree.rst
   MixedFreeResponse/toctree.rst
   FreeResponse/toctree.rst
   Stories/toctree.rst
   _hidden/toctree.rst


Index
::::::::::::::::::

* :ref:`genindex`
* :ref:`search`

.. |errors form| raw:: html

   <a href="https://forms.gle/4gMBsv4W71vG5mNe8" target="_blank" style="text-decoration:underline">errors form</a>

.. |interest form| raw:: html

   <a href="https://docs.google.com/forms/d/e/1FAIpQLSdN4JKrFnktQakID4sHBHBuBEHCvwv8YsSMBcVm1tB-nYUukA/viewform?usp=sf_link" target="_blank" style="text-decoration:underline">PD interest form</a>

.. |teaching CSAwesome group| raw:: html

   <a href="https://groups.google.com/forum/#!forum/teaching-csawesome" target="_blank" style="text-decoration:underline">teaching CSAwesome group</a>

.. |csawesome| raw:: html

   <a href="http://csawesome.org" target="_blank" style="text-decoration:underline">csawesome.org</a>

If you see errors or bugs, please report them with this |errors form|. If you are a teacher who is interested in CSAwesome PDs or community, please fill out this |interest form| and join the |teaching CSAwesome group| which will give you access to lesson plans at |csawesome|.

(last revised 1/6/2024)

© Copyright 2014-2024 Barb Ericson, Univ. Michigan; 2019-2024 Beryl Hoffman,
Elms College; 2023-2024 Peter Seibel, Berkeley High School. All rights reserved.

Created using `Runestone  <http://runestone.academy>`_.
